# EduROV server package

This package contains a server for use with the hardware described in https://github.com/simtind/edu-rover2-pcb, the client described in https://github.com/simtind/edu-rover2-client and the ROV described on the EduROV webpage.

To install, run ```py -m pip install edu-rover2```
To run the server, run ```edu-rover2```

## Building package

Make sure the newest version of pip is installed: ```py -m pip install --upgrade build```
Then from the edurov_server folder, run ```py -m build```